@@ -74,6 +74,9 @@ pub trait AstFold {
     fn fold_windowed(&mut self, windowed: Windowed) -> Result<Windowed> {
         fold_windowed(self, windowed)
     }
+    fn fold_query(&mut self, query: Query) -> Result<Query> {
+        fold_query(self, query)
+    }
 }
 
 pub fn fold_item<T: ?Sized + AstFold>(fold: &mut T, item: Item) -> Result<Item> {
@@ -140,6 +143,13 @@ pub fn fold_range<F: ?Sized + AstFold>(fold: &mut F, Range { start, end }: Range
     })
 }
 
+pub fn fold_query<F: ?Sized + AstFold>(fold: &mut F, query: Query) -> Result<Query> {
+    Ok(Query {
+        nodes: fold.fold_nodes(query.nodes)?,
+        ..query
+    })
+}
+
 pub fn fold_pipeline<T: ?Sized + AstFold>(fold: &mut T, pipeline: Pipeline) -> Result<Pipeline> {
     Ok(Pipeline {
         nodes: fold.fold_nodes(pipeline.nodes)?,
