@@ -79,7 +79,7 @@ impl Cli {
             Cli::Format(_) => crate::format(source)?.as_bytes().to_vec(),
             Cli::Debug(_) => {
                 let query = parse(source)?;
-                let (nodes, context) = semantic::resolve(query.nodes, None)?;
+                let (nodes, context) = semantic::resolve(query, None)?;
 
                 semantic::label_references(&nodes, &context, "".to_string(), source.to_string());
 
@@ -89,7 +89,7 @@ impl Cli {
                 let query = parse(source)?;
 
                 // resolve
-                let (nodes, context) = semantic::resolve(query.nodes, None)?;
+                let (nodes, context) = semantic::resolve(query, None)?;
 
                 let frames = semantic::collect_frames(nodes);
 
@@ -100,7 +100,7 @@ impl Cli {
             }
             Cli::Resolve(_) => {
                 let ast = parse(source)?;
-                let (ir, _) = semantic::resolve(ast.nodes, None)?;
+                let (ir, _) = semantic::resolve(ast, None)?;
 
                 serde_yaml::to_string(&ir)?.into_bytes()
             }
@@ -197,4 +197,37 @@ sort full
         sort full                                              # [?, full, gender]
         "###);
     }
+
+    #[test]
+    fn format_test() {
+        let output = Cli::execute(
+            &Cli::Format(CommandIO::default()),
+            r#"
+from table.subdivision
+ derive      `želva_means_turtle`   =    (`column with spaces` + 1) * 3
+group a_column (take 10 | sort b_column | derive [the_number = rank, last = lag 1 c_column] )
+        "#,
+        )
+        .unwrap();
+
+        // this test is here just to document behavior - the result is far from being correct:
+        // - indentation does not stack
+        // - operator precedence is not considered (parenthesis are not inserted for numerical
+        //   operations but are always inserted for function calls)
+        assert_snapshot!(String::from_utf8(output).unwrap().trim(),
+        @r###"
+        prql dialect:generic
+
+        from `table.subdivision`
+        derive `želva_means_turtle` = `column with spaces` + 1 * 3
+        group a_column (
+          take 10
+          sort b_column
+          derive [
+          the_number = rank,
+          last = (lag 1 c_column),
+        ]
+        )
+        "###);
+    }
 }
