@@ -12,7 +12,6 @@ pub use anyhow::Result;
 pub use cli::Cli;
 pub use error::{format_error, SourceLocation};
 pub use parser::parse;
-pub use semantic::resolve;
 pub use sql::translate;
 
 /// Compile a PRQL string into a SQL string.
@@ -26,7 +25,8 @@ pub fn compile(prql: &str) -> Result<String> {
 }
 
 pub fn resolve_and_translate(mut query: ast::Query) -> Result<String> {
-    let (nodes, context) = semantic::resolve(query.nodes, None)?;
+    // TODO: is there a way of avoiding this clone?
+    let (nodes, context) = semantic::resolve(query.clone(), None)?;
     query.nodes = nodes;
     translate(query, context)
 }
@@ -229,14 +229,28 @@ mod test {
         // GH-#822
         assert_display_snapshot!((compile(r###"
 prql dialect:postgres
-from some_schema.tablename
+table UPPER = (
+  from lower
+)
+from UPPER
+join some_schema.tablename [id]
         "###)?), @r###"
+        WITH "UPPER" AS (
+          SELECT
+            lower.*
+          FROM
+            lower
+        )
         SELECT
-          some_schema.tablename.*
+          "UPPER".*,
+          some_schema.tablename.*,
+          id
         FROM
-          some_schema.tablename
+          "UPPER"
+          JOIN some_schema.tablename USING(id)
         "###);
 
+        // GH-#852
         assert_display_snapshot!((compile(r###"
 prql dialect:bigquery
 from db.schema.table
@@ -1450,4 +1464,49 @@ take 20
         "###
         );
     }
+
+    #[test]
+    fn test_same_column_names() -> Result<()> {
+        // #820
+        let query = r###"
+table x = (
+  from x_table
+  select only_in_x = foo
+)
+
+table y = (
+  from y_table
+  select foo
+)
+
+from x
+join y [id]
+"###;
+
+        assert_display_snapshot!(compile(query)?,
+            @r###"
+        WITH x AS (
+          SELECT
+            foo AS only_in_x
+          FROM
+            x_table
+        ),
+        y AS (
+          SELECT
+            foo
+          FROM
+            y_table
+        )
+        SELECT
+          x.*,
+          y.*,
+          id
+        FROM
+          x
+          JOIN y USING(id)
+        "###
+        );
+
+        Ok(())
+    }
 }
