@@ -102,6 +102,7 @@ pub fn translate_query(query: Query, context: Context) -> Result<sql_ast::Query>
     Ok(main_query)
 }
 
+#[derive(Debug)]
 pub struct AtomicTable {
     name: Option<TableRef>,
     pipeline: Pipeline,
@@ -125,7 +126,7 @@ fn into_tables(nodes: Vec<Node>) -> Result<Vec<Table>> {
 
 fn table_to_sql_cte(table: AtomicTable, dialect: &dyn DialectHandler) -> Result<sql_ast::Cte> {
     let alias = sql_ast::TableAlias {
-        name: sql_ast::Ident::new(table.name.clone().unwrap().name),
+        name: translate_ident_part(table.name.as_ref().unwrap().clone().name, dialect),
         columns: vec![],
     };
     Ok(sql_ast::Cte {
@@ -789,7 +790,7 @@ fn translate_column(ident: String, dialect: &dyn DialectHandler) -> Vec<sql_ast:
 // We return a vec of SQL Idents because sqlparser sometimes uses
 // [ObjectName](sql_ast::ObjectName) and sometimes uses
 // [Expr::CompoundIdentifier](sql_ast::Expr::CompoundIdentifier), each of which
-// are `Vec<Ident>`.
+// contains `Vec<Ident>`.
 fn translate_ident(ident: String, dialect: &dyn DialectHandler) -> Vec<sql_ast::Ident> {
     let is_jinja = ident.starts_with("{{") && ident.ends_with("}}");
 
@@ -922,7 +923,7 @@ impl From<Vec<Node>> for AtomicTable {
 #[cfg(test)]
 mod test {
     use super::*;
-    use crate::{parser::parse, resolve};
+    use crate::{parser::parse, semantic::resolve};
     use insta::assert_yaml_snapshot;
     use serde_yaml::from_str;
 
@@ -990,7 +991,7 @@ mod test {
     }
 
     fn parse_and_resolve(prql: &str) -> Result<Pipeline> {
-        let (mut nodes, _) = resolve(parse(prql)?.nodes, None)?;
+        let (mut nodes, _) = resolve(parse(prql)?, None)?;
         let pipeline = nodes.remove(nodes.len() - 1).coerce_to_pipeline();
         Ok(pipeline)
     }
